Index: src/heap.h |
diff --git a/src/heap.h b/src/heap.h |
index e0ffa63e9abdf8678925b12cef99b154ef76163a..4d20a8dafb6000475c379cc8a7716993ee3acee3 100644 |
--- a/src/heap.h |
+++ b/src/heap.h |
@@ -1868,13 +1868,13 @@ class Heap { |
void CheckpointObjectStats(); |
// We don't use a ScopedLock here since we want to lock the heap |
// only when FLAG_parallel_recompilation is true. |
class RelocationLock { |
public: |
explicit RelocationLock(Heap* heap); |
~RelocationLock() { |
- if (FLAG_parallel_recompilation) { |
+ if (FLAG_concurrent_recompilation) { |
#ifdef DEBUG |
heap_->relocation_mutex_locked_by_optimizer_thread_ = false; |
#endif // DEBUG |
@@ -1868,13 +1868,13 @@ class Heap { |
void CheckpointObjectStats(); |
// We don't use a ScopedLock here since we want to lock the heap |
- // only when FLAG_parallel_recompilation is true. |
+ // only when FLAG_concurrent_recompilation is true. |
class RelocationLock { |
public: |